@@ -57,7 +57,7 @@ impl Backend for GemBackend {
             //       uninstalling the ruby version used to install the gem will break the
             //       gem. We should find a way to fix this.
             // .arg("--env-shebang")
-            .with_pr(ctx.pr.as_ref())
+            .with_pr(&ctx.pr)
             .envs(self.dependency_env()?)
             .execute()?;
 
