@@ -102,17 +102,22 @@ impl TasksInfo {
         let (spec, _) = task.parse_usage_spec(None, env)?;
         let o = json!({
             "name": task.display_name(),
-            "aliases": task.aliases.join(", "),
-            "description": task.description.to_string(),
+            "aliases": task.aliases,
+            "description": task.description,
             "source": task.config_source,
-            "depends": task.depends.iter().join(", "),
-            "depends_post": task.depends_post.iter().join(", "),
+            "depends": task.depends,
+            "depends_post": task.depends_post,
+            "wait_for": task.wait_for,
             "env": task.env,
             "dir": task.dir,
             "hide": task.hide,
             "raw": task.raw,
             "sources": task.sources,
             "outputs": task.outputs,
+            "shell": task.shell,
+            "quiet": task.quiet,
+            "silent": task.silent,
+            "tools": task.tools,
             "run": task.run(),
             "file": task.file,
             "usage_spec": spec,
