@@ -114,13 +114,7 @@ static RUNNING_PIDS: Lazy<Mutex<HashSet<u32>>> = Lazy::new(Default::default);
 
 impl<'a> CmdLineRunner<'a> {
     pub fn new<P: AsRef<OsStr>>(program: P) -> Self {
-        let mut cmd = if cfg!(windows) {
-            let mut cmd = Command::new("cmd.exe");
-            cmd.arg("/c").arg(program);
-            cmd
-        } else {
-            Command::new(program)
-        };
+        let mut cmd = Command::new(program);
         cmd.stdin(Stdio::null());
         cmd.stdout(Stdio::piped());
         cmd.stderr(Stdio::piped());
