@@ -26,7 +26,7 @@ pub fn hash_sha256_to_str(s: &str) -> String {
     format!("{:x}", hasher.finalize())
 }
 
-pub fn file_hash_sha256(path: &Path, pr: Option<&dyn SingleReport>) -> Result<String> {
+pub fn file_hash_sha256(path: &Path, pr: Option<&Box<dyn SingleReport>>) -> Result<String> {
     let use_external_hasher = file::size(path).unwrap_or_default() > 50 * 1024 * 1024;
     if use_external_hasher && file::which("sha256sum").is_some() {
         let out = cmd!("sha256sum", path).read()?;
@@ -36,7 +36,7 @@ pub fn file_hash_sha256(path: &Path, pr: Option<&dyn SingleReport>) -> Result<St
     }
 }
 
-fn file_hash_prog<D>(path: &Path, pr: Option<&dyn SingleReport>) -> Result<String>
+fn file_hash_prog<D>(path: &Path, pr: Option<&Box<dyn SingleReport>>) -> Result<String>
 where
     D: Digest + Write,
     D::OutputSize: std::ops::Add,
@@ -66,7 +66,7 @@ where
 pub fn ensure_checksum(
     path: &Path,
     checksum: &str,
-    pr: Option<&dyn SingleReport>,
+    pr: Option<&Box<dyn SingleReport>>,
     algo: &str,
 ) -> Result<()> {
     let use_external_hasher = file::size(path).unwrap_or(u64::MAX) > 10 * 1024 * 1024;
